@@ -165,6 +165,7 @@ void cFeature::fillfeaturetypes() {
   featuretypes["Spikecount"] = "int";
   featuretypes["Spikecount_stimint"] = "int";
   featuretypes["AHP_depth"] = "double";
+  featuretypes["AHP_depth_slow"] = "double";
   featuretypes["amp_drop_first_second"] = "double";
   featuretypes["amp_drop_first_last"] = "double";
   featuretypes["amp_drop_second_last"] = "double";
@@ -263,6 +264,8 @@ void cFeature::fillfeaturetypes() {
 
   featuretypes["interburst_min_indices"] = "int";
   featuretypes["interburst_min_values"] = "double";
+  featuretypes["postburst_min_indices"] = "int";
+  featuretypes["postburst_min_values"] = "double";
   featuretypes["time_to_interburst_min"] = "double";
 
   // end of feature types
